@@ -318,16 +318,15 @@ namespace gnote {
       on_open_note_new_window(note);
     }
     else {
-      present_note(note);
+      if(!present_active(note)) {
+        present_note(note);
+      }
     }
   }
 
   void NoteRecentChanges::on_open_note_new_window(const Note::Ptr & note)
   {
-    MainWindow & window = IGnote::obj().new_main_window();
-    window.present();
-    window.present_note(note);
-    window.close_on_escape(true);
+    present_in_new_window(note, true);
   }
 
   void NoteRecentChanges::on_delete_note()
@@ -534,12 +533,21 @@ namespace gnote {
     m_embedded_toolbar.remove();
   }
 
+  bool NoteRecentChanges::contains(EmbeddableWidget & widget)
+  {
+    FOREACH(EmbeddableWidget *wgt, m_embedded_widgets) {
+      if(dynamic_cast<EmbeddableWidget*>(wgt) == &widget) {
+        return true;
+      }
+    }
+
+    return false;
+  }
+
   bool NoteRecentChanges::is_foreground(EmbeddableWidget & widget)
   {
-    std::vector<Gtk::Widget*> current = m_embed_box.get_children();
-    for(std::vector<Gtk::Widget*>::iterator iter = current.begin();
-        iter != current.end(); ++iter) {
-      if(dynamic_cast<EmbeddableWidget*>(*iter) == &widget) {
+    FOREACH(Gtk::Widget *wgt, m_embed_box.get_children()) {
+      if(dynamic_cast<EmbeddableWidget*>(wgt) == &widget) {
         return true;
       }
     }
@@ -640,9 +648,7 @@ namespace gnote {
       else {
         m_find_next_prev_box.hide();
       }
-      if(m_search_button.get_active() && m_search_entry.get_text() != "") {
-        searchable_item.perform_search(m_search_entry.get_text());
-      }
+      searchable_item.perform_search(m_search_button.get_active() ? m_search_entry.get_text() : "");
     }
     catch(std::bad_cast &) {
       m_search_button.set_active(false);
