@@ -124,7 +124,7 @@ std::string SearchNotesWidget::get_name() const
 {
   notebooks::Notebook::Ptr selected_notebook = get_selected_notebook();
   if(!selected_notebook
-     || std::tr1::dynamic_pointer_cast<notebooks::AllNotesNotebook>(selected_notebook)) {
+     || dynamic_pointer_cast<notebooks::AllNotesNotebook>(selected_notebook)) {
     return "";
   }
   return selected_notebook->get_name();
@@ -178,7 +178,7 @@ void SearchNotesWidget::perform_search()
 
   // Search using the currently selected notebook
   notebooks::Notebook::Ptr selected_notebook = get_selected_notebook();
-  if (std::tr1::dynamic_pointer_cast<notebooks::SpecialNotebook>(selected_notebook)) {
+  if(dynamic_pointer_cast<notebooks::SpecialNotebook>(selected_notebook)) {
     selected_notebook = notebooks::Notebook::Ptr();
   }
 
@@ -314,7 +314,7 @@ void SearchNotesWidget::notebook_text_cell_data_func(Gtk::CellRenderer * rendere
 
   crt->property_text() = notebook->get_name();
 
-  if(std::tr1::dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
+  if(dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
     // Bold the "Special" Notebooks
     crt->property_markup() = str(boost::format("<span weight=\"bold\">%1%</span>")
                                  % notebook->get_name());
@@ -331,7 +331,7 @@ void SearchNotesWidget::on_notebook_row_edited(const Glib::ustring& /*tree_path*
     return;
   }
   notebooks::Notebook::Ptr old_notebook = this->get_selected_notebook();
-  if(std::tr1::dynamic_pointer_cast<notebooks::SpecialNotebook>(old_notebook)) {
+  if(dynamic_pointer_cast<notebooks::SpecialNotebook>(old_notebook)) {
     return;
   }
   notebooks::Notebook::Ptr new_notebook = notebooks::NotebookManager::obj()
@@ -382,7 +382,7 @@ void SearchNotesWidget::on_notebook_selection_changed()
       m_selected_tags.insert(notebook->get_tag());
     }
     bool allow_edit = false;
-    if(std::tr1::dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
+    if(dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
       m_delete_notebook_action->set_sensitive(false);
       m_rename_notebook_action->set_sensitive(false);
     }
@@ -474,7 +474,7 @@ void SearchNotesWidget::select_all_notes_notebook()
   for(Gtk::TreeIter iter = model->children().begin(); iter; ++iter) {
     notebooks::Notebook::Ptr notebook;
     iter->get_value(0, notebook);
-    if(std::tr1::dynamic_pointer_cast<notebooks::AllNotesNotebook>(notebook) != NULL) {
+    if(dynamic_pointer_cast<notebooks::AllNotesNotebook>(notebook) != NULL) {
       m_notebooksTree->get_selection()->select(iter);
       break;
     }
@@ -578,12 +578,6 @@ bool SearchNotesWidget::filter_notes(const Gtk::TreeIter & iter)
     return false;
   }
 
-  // Don't show the template notes in the list
-  Tag::Ptr template_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
-  if(note->contains_tag(template_tag)) {
-    return false;
-  }
-
   notebooks::Notebook::Ptr selected_notebook = get_selected_notebook();
   if(!selected_notebook || !selected_notebook->contains_note(note)) {
     return false;
@@ -1320,7 +1314,7 @@ void SearchNotesWidget::new_note()
 {
   Note::Ptr note;
   notebooks::Notebook::Ptr notebook = get_selected_notebook();
-  if(!notebook || std::tr1::dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
+  if(!notebook || dynamic_pointer_cast<notebooks::SpecialNotebook>(notebook)) {
     // Just create a standard note (not in a notebook)
     note = m_manager.create();
   }
